@@ -35,7 +35,6 @@ def get_pairs(word):
 
 
 class Encoder:
-
     def __init__(self, encoder, bpe_merges):
         self.encoder = encoder
         self.decoder = {v: k for k, v in self.encoder.items()}
@@ -160,13 +159,8 @@ def get_encoder(encoder_file, bpe_file):
             bpe_merges=bpe_merges,
         )
 
-
 def from_pretrained(pretrained_model_file=None):
-    vocab_file = 'cog-pretrain.vocab'
-    model_file = 'cog-pretrain.model'
     if pretrained_model_file is None:
-        cache_dir = os.path.join(os.path.dirname(__file__), 'vocabs')
         model_id = _get_model_id("GLM-large-ch")
-        _get_vocab_path(cache_dir, vocab_file, model_id, rank=0)
-        _get_vocab_path(cache_dir, model_file, model_id, rank=0)
+        _get_vocab_path(pretrained_model_file, model_id, rank=0)
     return get_encoder(pretrained_model_file, "")
